/*
Copyright (c) 2019-2022 Digital Energy Cloud Solutions LLC. All Rights Reserved.
Authors:
Petr Krutov, <petr.krutov@digitalenergy.online>
Stanislav Solovev, <spsolovev@digitalenergy.online>
Kasim Baybikov, <kmbaybikov@basistech.ru>

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package provider

import (
	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/account"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/bservice"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/disks"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/extnet"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/flipgroup"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/image"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/k8s"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/kvmvm"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/lb"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/locations"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/rg"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/snapshot"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/stack"
	"repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudapi/vins"

	cb_account "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/account"
	cb_disks "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/disks"
	cb_extnet "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/extnet"
	cb_grid "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/grid"
	cb_image "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/image"
	cb_pcidevice "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/pcidevice"
	cb_rg "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/rg"
	cb_sep "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/sep"
	cb_vgpu "repository.basistech.ru/BASIS/terraform-provider-decort/internal/service/cloudbroker/vgpu"
)

func newDataSourcesMap() map[string]*schema.Resource {
	return map[string]*schema.Resource{
		"decort_account":                        account.DataSourceAccount(),
		"decort_resgroup":                       rg.DataSourceResgroup(),
		"decort_kvmvm":                          kvmvm.DataSourceCompute(),
		"decort_kvmvm_list":                     kvmvm.DataSourceComputeList(),
		"decort_kvmvm_audits":                   kvmvm.DataSourceComputeAudits(),
		"decort_kvmvm_get_audits":               kvmvm.DataSourceComputeGetAudits(),
		"decort_kvmvm_get_console_url":          kvmvm.DataSourceComputeGetConsoleUrl(),
		"decort_kvmvm_get_log":                  kvmvm.DataSourceComputeGetLog(),
		"decort_kvmvm_pfw_list":                 kvmvm.DataSourceComputePfwList(),
		"decort_kvmvm_user_list":                kvmvm.DataSourceComputeUserList(),
		"decort_kvmvm_snapshot_usage":           kvmvm.DataSourceComputeSnapshotUsage(),
		"decort_k8s":                            k8s.DataSourceK8s(),
		"decort_k8s_list":                       k8s.DataSourceK8sList(),
		"decort_k8s_list_deleted":               k8s.DataSourceK8sListDeleted(),
		"decort_k8s_wg":                         k8s.DataSourceK8sWg(),
		"decort_k8s_wg_list":                    k8s.DataSourceK8sWgList(),
		"decort_k8s_computes":                   k8s.DataSourceK8sComputes(),
		"decort_k8ci_list":                      k8s.DataSourceK8CIList(),
		"decort_vins":                           vins.DataSourceVins(),
		"decort_vins_list":                      vins.DataSourceVinsList(),
		"decort_vins_audits":                    vins.DataSourceVinsAudits(),
		"decort_vins_ip_list":                   vins.DataSourceVinsIpList(),
		"decort_vins_list_deleted":              vins.DataSourceVinsListDeleted(),
		"decort_vins_ext_net_list":              vins.DataSourceVinsExtNetList(),
		"decort_vins_nat_rule_list":             vins.DataSourceVinsNatRuleList(),
		"decort_vins_static_route_list":        vins.DataSourceStaticRouteList(),
		"decort_vins_static_route":              vins.DataSourceStaticRoute(),
		"decort_snapshot_list":                  snapshot.DataSourceSnapshotList(),
		"decort_disk":                           disks.DataSourceDisk(),
		"decort_disk_list":                      disks.DataSourceDiskList(),
		"decort_rg_list":                        rg.DataSourceRgList(),
		"decort_rg_affinity_group_computes":     rg.DataSourceRgAffinityGroupComputes(),
		"decort_rg_affinity_groups_list":        rg.DataSourceRgAffinityGroupsList(),
		"decort_rg_affinity_groups_get":         rg.DataSourceRgAffinityGroupsGet(),
		"decort_rg_audits":                      rg.DataSourceRgAudits(),
		"decort_rg_list_computes":               rg.DataSourceRgListComputes(),
		"decort_rg_list_deleted":                rg.DataSourceRgListDeleted(),
		"decort_rg_list_lb":                     rg.DataSourceRgListLb(),
		"decort_rg_list_pfw":                    rg.DataSourceRgListPfw(),
		"decort_rg_list_vins":                   rg.DataSourceRgListVins(),
		"decort_rg_usage":                       rg.DataSourceRgUsage(),
		"decort_disk_list_types_detailed":       disks.DataSourceDiskListTypesDetailed(),
		"decort_disk_list_types":                disks.DataSourceDiskListTypes(),
		"decort_disk_list_deleted":              disks.DataSourceDiskListDeleted(),
		"decort_disk_list_unattached":           disks.DataSourceDiskListUnattached(),
		"decort_disk_snapshot":                  disks.DataSourceDiskSnapshot(),
		"decort_disk_snapshot_list":             disks.DataSourceDiskSnapshotList(),
		"decort_account_list":                   account.DataSourceAccountList(),
		"decort_account_computes_list":          account.DataSourceAccountComputesList(),
		"decort_account_disks_list":             account.DataSourceAccountDisksList(),
		"decort_account_vins_list":              account.DataSourceAccountVinsList(),
		"decort_account_audits_list":            account.DataSourceAccountAuditsList(),
		"decort_account_rg_list":                account.DataSourceAccountRGList(),
		"decort_account_consumed_units":         account.DataSourceAccountConsumedUnits(),
		"decort_account_consumed_units_by_type": account.DataSourceAccountConsumedUnitsByType(),
		"decort_account_reserved_units":         account.DataSourceAccountReservedUnits(),
		"decort_account_templates_list":         account.DataSourceAccountTemplatessList(),
		"decort_account_deleted_list":           account.DataSourceAccountDeletedList(),
		"decort_account_flipgroups_list":        account.DataSourceAccountFlipGroupsList(),
		"decort_bservice_list":                  bservice.DataSourceBasicServiceList(),
		"decort_bservice":                       bservice.DataSourceBasicService(),
		"decort_bservice_snapshot_list":         bservice.DataSourceBasicServiceSnapshotList(),
		"decort_bservice_group":                 bservice.DataSourceBasicServiceGroup(),
		"decort_bservice_deleted_list":          bservice.DataSourceBasicServiceDeletedList(),
		"decort_extnet_list":                    extnet.DataSourceExtnetList(),
		"decort_extnet_computes_list":           extnet.DataSourceExtnetComputesList(),
		"decort_extnet":                         extnet.DataSourceExtnet(),
		"decort_extnet_default":                 extnet.DataSourceExtnetDefault(),
		"decort_locations_list":                 locations.DataSourceLocationsList(),
		"decort_location_url":                   locations.DataSourceLocationUrl(),
		"decort_image_list":                     image.DataSourceImageList(),
		"decort_image":                          image.DataSourceImage(),
		"decort_lb":                             lb.DataSourceLB(),
		"decort_lb_list":                        lb.DataSourceLBList(),
		"decort_lb_list_deleted":                lb.DataSourceLBListDeleted(),
		"decort_flipgroup":                      flipgroup.DataSourceFlipgroup(),
		"decort_flipgroup_list":                 flipgroup.DataSourceFlipGroupList(),
		"decort_stack":                          stack.DataSourceStack(),
		"decort_stack_list":                     stack.DataSourceStackList(),

		"decort_cb_account":                 cb_account.DataSourceAccount(),
		"decort_cb_account_list":            cb_account.DataSourceAccountList(),
		"decort_cb_account_computes_list":   cb_account.DataSourceAccountComputesList(),
		"decort_cb_account_deleted_list":    cb_account.DataSourceAccountDeletedList(),
		"decort_cb_account_disks_list":      cb_account.DataSourceAccountDisksList(),
		"decort_cb_account_flipgroups_list": cb_account.DataSourceAccountFlipGroupsList(),
		"decort_cb_account_rg_list":         cb_account.DataSourceAccountRGList(),
		"decort_cb_account_vins_list":       cb_account.DataSourceAccountVinsList(),
		"decort_cb_account_audits_list":     cb_account.DataSourceAccountAuditsList(),
		"decort_cb_extnet":                  cb_extnet.DataSourceExtnetCB(),
		"decort_cb_extnet_list":             cb_extnet.DataSourceExtnetListCB(),
		"decort_cb_extnet_default":          cb_extnet.DataSourceExtnetDefaultCB(),
		"decort_cb_disk":                    cb_disks.DataSourceDisk(),
		"decort_cb_disk_list":               cb_disks.DataSourceDiskList(),
		"decort_cb_image":                   cb_image.DataSourceImage(),
		"decort_cb_grid":                    cb_grid.DataSourceGrid(),
		"decort_cb_grid_list":               cb_grid.DataSourceGridList(),
		"decort_cb_image_list":              cb_image.DataSourceImageList(),
		"decort_cb_image_list_stacks":       cb_image.DataSourceImageListStacks(),
		"decort_cb_pcidevice":               cb_pcidevice.DataSourcePcidevice(),
		"decort_cb_pcidevice_list":          cb_pcidevice.DataSourcePcideviceList(),
		"decort_cb_sep_list":                cb_sep.DataSourceSepList(),
		"decort_cb_sep":                     cb_sep.DataSourceSep(),
		"decort_cb_sep_consumption":         cb_sep.DataSourceSepConsumption(),
		"decort_cb_sep_disk_list":           cb_sep.DataSourceSepDiskList(),
		"decort_cb_sep_config":              cb_sep.DataSourceSepConfig(),
		"decort_cb_sep_pool":                cb_sep.DataSourceSepPool(),
		"decort_cb_vgpu":                    cb_vgpu.DataSourceVGPU(),
		"decort_cb_rg_list":                 cb_rg.DataSourceRgList(),
	}

}
